@@ -39,8 +39,11 @@ void exit_with_help()
 	"	11 -- L2-regularized L2-loss support vector regression (primal)\n"
 	"	12 -- L2-regularized L2-loss support vector regression (dual)\n"
 	"	13 -- L2-regularized L1-loss support vector regression (dual)\n"
+	"  for outlier detection\n"
+	"	21 -- one-class support vector machine (dual)\n"
 	"-c cost : set the parameter C (default 1)\n"
 	"-p epsilon : set the epsilon in loss function of SVR (default 0.1)\n"
+	"-n nu : set the parameter nu of one-class SVM (default 0.5)\n"
 	"-e epsilon : set tolerance of termination criterion\n"
 	"	-s 0 and 2\n"
 	"		|f'(w)|_2 <= eps*min(pos,neg)/l*|f'(w0)|_2,\n"
@@ -48,8 +51,8 @@ void exit_with_help()
 	"		positive/negative data (default 0.01)\n"
 	"	-s 11\n"
 	"		|f'(w)|_2 <= eps*|f'(w0)|_2 (default 0.0001)\n"
-	"	-s 1, 3, 4 and 7\n"
-	"		Dual maximal violation <= eps; similar to libsvm (default 0.1)\n"
+	"	-s 1, 3, 4, 7, and 21\n"
+	"		Dual maximal violation <= eps; similar to libsvm (default 0.1 except 0.01 for -s 21)\n"
 	"	-s 5 and 6\n"
 	"		|f'(w)|_1 <= eps*min(pos,neg)/l*|f'(w0)|_1,\n"
 	"		where f is the primal function (default 0.01)\n"
@@ -57,6 +60,8 @@ void exit_with_help()
 	"		|f'(alpha)|_1 <= eps |f'(alpha0)|,\n"
 	"		where f is the dual function (default 0.1)\n"
 	"-B bias : if bias >= 0, instance x becomes [x; bias]; if < 0, no bias term added (default -1)\n"
+	"-R : not regularize the bias; must with -B 1 to have the bias; DON'T use this unless you know what it is\n"
+	"	(for -s 0, 2, 5, 6, 11)\n"
 	"-wi weight: weights adjust the parameter C of different classes (see README for details)\n"
 	"-v n: n-fold cross validation mode\n"
 	"-C : find parameters (C for -s 0, 2 and C, p for -s 11)\n"
@@ -92,6 +97,8 @@ void do_find_parameters(double *best_C, double *best_p, double *best_score)
 		start_p = param.p;
 	else
 		start_p = -1.0;
+
+	mexPrintf("Doing parameter search with %d-fold cross validation.\n", nr_fold);
 	find_parameters(&prob, &param, nr_fold, start_C, start_p, best_C, best_p, best_score);
 
 	if(param.solver_type == L2R_LR || param.solver_type == L2R_L2LOSS_SVC)
@@ -157,12 +164,14 @@ int parse_command_line(int nrhs, const mxArray *prhs[], char *model_file_name)
 	// default values
 	param.solver_type = L2R_L2LOSS_SVC_DUAL;
 	param.C = 1;
-	param.eps = INF; // see setting below
 	param.p = 0.1;
+	param.nu = 0.5;
+	param.eps = INF; // see setting below
 	param.nr_weight = 0;
 	param.weight_label = NULL;
 	param.weight = NULL;
 	param.init_sol = NULL;
+	param.regularize_bias = 1;
 	flag_cross_validation = 0;
 	col_format_flag = 0;
 	flag_C_specified = 0;
@@ -196,7 +205,8 @@ int parse_command_line(int nrhs, const mxArray *prhs[], char *model_file_name)
 	{
 		if(argv[i][0] != '-') break;
 		++i;
-		if(i>=argc && argv[i-1][1] != 'q' && argv[i-1][1] != 'C') // since options -q and -C have no parameter
+		if(i>=argc && argv[i-1][1] != 'q' && argv[i-1][1] != 'C'
+				&& argv[i-1][1] != 'R') // since options -q and -C have no parameter
 			return 1;
 		switch(argv[i-1][1])
 		{
@@ -212,6 +222,9 @@ int parse_command_line(int nrhs, const mxArray *prhs[], char *model_file_name)
 				param.p = atof(argv[i]);
 				flag_p_specified = 1;
 				break;
+			case 'n':
+				param.nu = atof(argv[i]);
+				break;
 			case 'e':
 				param.eps = atof(argv[i]);
 				break;
@@ -242,6 +255,10 @@ int parse_command_line(int nrhs, const mxArray *prhs[], char *model_file_name)
 				flag_find_parameters = 1;
 				i--;
 				break;
+			case 'R':
+				param.regularize_bias = 0;
+				i--;
+				break;
 			default:
 				mexPrintf("unknown option\n");
 				return 1;
@@ -292,6 +309,9 @@ int parse_command_line(int nrhs, const mxArray *prhs[], char *model_file_name)
 			case L2R_L2LOSS_SVR_DUAL:
 				param.eps = 0.1;
 				break;
+			case ONECLASS_SVM:
+				param.eps = 0.01;
+				break;
 		}
 	}
 	return 0;
